QCG-PilotJob Executor API
=======
QCG-PilotJob Executor API, by imitation of the Python Executor API, 
provides a relatively easy way of usage of QCG-PilotJob. It is targeted to
fulfil needs of basic execution scenarios, but may be useful also for more advanced ones.

**Author**: Piotr Kopta <pkopta@man.poznan.pl>, Tomasz Piontek <piontek@man.poznan.pl>, Bartosz Bosak <bbosak@man.poznan.pl>

*Copyright (C) 2017-2021 Poznan Supercomputing and Networking Center*

## Documentation
The documentation of the QCG-PilotJob system is available at https://qcg-pilotjob.readthedocs.org

## Installation
The latest stable version of QCG-PilotJob Executor API can be installed with pip

```bash
$ pip install qcg-pilotjob-executor-api
```